@@ -11,13 +11,14 @@ import os
 import re
 import textwrap
 import marshal
+import warnings
 
-from setuptools.extern import six
+import six
 
 from pkg_resources import get_build_platform, Distribution, ensure_directory
 from pkg_resources import EntryPoint
 from setuptools.extension import Library
-from setuptools import Command
+from setuptools import Command, SetuptoolsDeprecationWarning
 
 try:
     # Python 2.7 or >=3.2
@@ -39,6 +40,7 @@ def strip_module(filename):
         filename = filename[:-6]
     return filename
 
+
 def sorted_walk(dir):
     """Do os.walk in a reproducible way,
     independent of indeterministic filesystem readdir order
@@ -48,6 +50,7 @@ def sorted_walk(dir):
         files.sort()
         yield base, dirs, files
 
+
 def write_stub(resource, pyfile):
     _stub_template = textwrap.dedent("""
         def __bootstrap__():
@@ -252,15 +255,17 @@ class bdist_egg(Command):
 
                     pattern = r'(?P<name>.+)\.(?P<magic>[^.]+)\.pyc'
                     m = re.match(pattern, name)
-                    path_new = os.path.join(base, os.pardir, m.group('name') + '.pyc')
-                    log.info("Renaming file from [%s] to [%s]" % (path_old, path_new))
+                    path_new = os.path.join(
+                        base, os.pardir, m.group('name') + '.pyc')
+                    log.info(
+                        "Renaming file from [%s] to [%s]"
+                        % (path_old, path_new))
                     try:
                         os.remove(path_new)
                     except OSError:
                         pass
                     os.rename(path_old, path_new)
 
-
     def zip_safe(self):
         safe = getattr(self.distribution, 'zip_safe', None)
         if safe is not None:
@@ -274,13 +279,19 @@ class bdist_egg(Command):
         if ep is None:
             return 'w'  # not an eggsecutable, do it the usual way.
 
+        warnings.warn(
+            "Eggsecutables are deprecated and will be removed in a future "
+            "version.",
+            SetuptoolsDeprecationWarning
+        )
+
         if not ep.attrs or ep.extras:
             raise DistutilsSetupError(
                 "eggsecutable entry point (%r) cannot have 'extras' "
                 "or refer to a module" % (ep,)
             )
 
-        pyver = sys.version[:3]
+        pyver = '{}.{}'.format(*sys.version_info)
         pkg = ep.module_name
         full = '.'.join(ep.attrs)
         base = ep.attrs[0]
@@ -407,10 +418,12 @@ def scan_module(egg_dir, base, name, stubs):
         return True  # Extension module
     pkg = base[len(egg_dir) + 1:].replace(os.sep, '.')
     module = pkg + (pkg and '.' or '') + os.path.splitext(name)[0]
-    if sys.version_info < (3, 3):
+    if six.PY2:
         skip = 8  # skip magic & date
-    else:
+    elif sys.version_info < (3, 7):
         skip = 12  # skip magic & date & file size
+    else:
+        skip = 16  # skip magic & reserved? & date & file size
     f = open(filename, 'rb')
     f.read(skip)
     code = marshal.load(f)
